import unittest

from utils import WWW, Git, Image, LatLng, Tweet, _, _log, hashx, mr, xmlx


class TestCase(unittest.TestCase):
    def test_init(self):
        for x in [WWW, Git, Tweet, _, _log, hashx, mr, xmlx, Image, LatLng]:
            self.assertIsNotNone(x)



from utils_base import (DAYS_IN, SECONDS_IN, TIME_FORMAT_DATE,
                        TIME_FORMAT_DATE_ID, TIME_FORMAT_TIME,
                        TIME_FORMAT_TIME_ID, TIMEZONE_OFFSET, CSVFile, Dict,
                        Directory, File, FiledVariable, Image, JSONFile,
                        LatLng, LatLngLK, List, Log, PDFFile, String, Table,
                        TableRow, Time, TimeDelta, TimeFormat, TimeUnit,
                        TSVFile, XSVFile, Zip, _, _log, get_date_id,
                        get_time_id, hashx, mr, xmlx)
from utils_git import Git
from utils_twitter import Tweet, Twitter
from utils_www import WWW
